#[non_exhaustive]pub enum PrimitiveError {
Empty,
TooShort {
min: usize,
actual: usize,
},
TooLong {
max: usize,
actual: usize,
},
OutOfRange {
min: u128,
max: u128,
actual: u128,
},
Invalid {
message: &'static str,
},
}Expand description
Error returned when a primitive value fails validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The value was empty or contained only whitespace.
TooShort
The value was shorter than the minimum allowed length.
TooLong
The value was longer than the maximum allowed length.
OutOfRange
The value was outside the inclusive allowed range.
Invalid
The value did not match the expected format or pattern.