pub struct HexString(/* private fields */);Expand description
String of valid hexadecimal characters, with optional 0x/0X prefix.
Implementations
Sourceimpl HexString
impl HexString
Sourcepub fn new(value: impl Into<String>) -> PrimitiveResult<Self>
pub fn new(value: impl Into<String>) -> PrimitiveResult<Self>
Creates a new HexString. Returns Invalid if any character is not a
valid hex digit (after stripping an optional 0x/0X prefix).
Sourcepub fn into_inner(self) -> String
pub fn into_inner(self) -> String
Consumes the wrapper and returns the inner string.
Sourcepub fn has_prefix(&self) -> bool
pub fn has_prefix(&self) -> bool
Returns true if the value was stored with a 0x/0X prefix.
Sourcepub fn hex_digits(&self) -> &str
pub fn hex_digits(&self) -> &str
Returns only the hex digit characters, without any 0x/0X prefix.