Type-safe primitives for constrained values.
reliakit-primitives provides small owned wrapper types for values that
should satisfy common constraints before they move through an application or
library boundary.
The crate has no dependencies and forbids unsafe code.
Re-exports
pub use bounded::BoundedStr;pub use collections::NonEmptyVec;pub use duration::HumanDuration;pub use error::PrimitiveError;pub use error::PrimitiveResult;pub use non_empty::NonEmptyStr;pub use numeric::ByteSize;pub use numeric::Percent;pub use numeric::PercentageF64;pub use numeric::Port;pub use numeric::PositiveFloat;pub use numeric::PositiveInt;pub use semver::SemVer;pub use text::Email;pub use text::HexString;pub use text::HttpUrl;pub use text::Slug;pub use uuid::Uuid;